@@ -1,21 +1,14 @@
-# Copyright (C) 2014 - 2018  Jack O. Wasey
-#
-# This file is part of icd.
-#
-# icd is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# icd is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with icd. If not, see <http:#www.gnu.org/licenses/>.
-
-# nocov start
+.dl_icd10cm_xml <- function(ver = "2019", ...) {
+  # http://www.cdc.gov/nchs/data/icd/icd10cm/2016/ICD10CM_FY2016_Full_XML.ZIP
+  s <- .icd10cm_sources[[ver]]
+  .unzip_to_data_raw(
+    url = paste0(s$base_url, s$dx_xml_zip),
+    file_name = s$dx_xml,
+    save_name = .get_versioned_raw_file_name(s$dx_xml, ver),
+    dl_msg = "Downloading ICD-10-CM 2019 XML",
+    ...
+  )
+}
 
 #' Get sub-chapters from the 2016 XML for ICD-10-CM
 #'
@@ -27,21 +20,17 @@
 #' chapter Neoplasms (\code{C00-D49}). A way of determining whether there are
 #' extra levels would be to check the XML tree depth for a member of each
 #' putative sub-chapter.
-#' @template save_data
+#' @template save_pkg_data
 #' @keywords internal datagen
-icd10cm_extract_sub_chapters <- function(save_data = FALSE, offline = TRUE) {
-  assert_flag(save_data)
-  f_info <- icd10cm_get_xml_file(offline = offline)
+#' @noRd
+.icd10cm_extract_sub_chapters <- function(save_pkg_data = FALSE,
+                                          ...) {
+  stopifnot(is.logical(save_pkg_data))
+  f_info <- .dl_icd10cm_xml(...)
   stopifnot(!is.null(f_info))
   j <- xml2::read_xml(f_info$file_path)
-
-  # using magrittr::equals and extract because I don't want to import them. See
-  # \code{icd-package.R} for what is imported. No harm in being explicit, since
-  # :: will do an implicit requireNamespace.
   xml2::xml_name(xml2::xml_children(j)) == "chapter" -> chapter_indices
-  # could do xpath, but harder to loop
-  xml2::xml_children(j) %>%
-    magrittr::extract(chapter_indices) -> chaps
+  chaps <- xml2::xml_children(j)[chapter_indices]
   icd10_sub_chapters <- list()
   for (chap in chaps) {
     c_kids <- xml2::xml_children(chap)
@@ -49,7 +38,7 @@ icd10cm_extract_sub_chapters <- function(save_data = FALSE, offline = TRUE) {
     subchaps <- c_kids[subchap_indices]
     for (subchap in subchaps) {
       new_sub_chap_range <-
-        chapter_to_desc_range.icd10(
+        .chapter_to_desc_range.icd10(
           xml2::xml_text(
             xml2::xml_children(
               subchap
@@ -67,13 +56,20 @@ icd10cm_extract_sub_chapters <- function(save_data = FALSE, offline = TRUE) {
       }
       # there is a defined Y09 in both ICD-10 WHO and CM, but the range is
       # incorrectly specified (in 2016 version of XML, at least)
-      if (new_sub_chap_range[[1]]["end"] == "Y08")
+      if (new_sub_chap_range[[1]]["end"] == "Y08") {
         new_sub_chap_range[[1]]["end"] <- "Y09"
+      }
       icd10_sub_chapters <- append(icd10_sub_chapters, new_sub_chap_range)
-    } #subchaps
-  } #chapters
-  if (save_data) save_in_data_dir(icd10_sub_chapters)
+    } # subchaps
+  } # chapters
+  # reorder quirk C7A, C7B, D3A) which are actually subchapters. We should
+  # already have included num-alpha-num codes which are within ranges.
+  c7ab <- icd10_sub_chapters[35:36]
+  icd10_sub_chapters[35:36] <- NULL
+  icd10_sub_chapters <- append(icd10_sub_chapters, c7ab, after = 35)
+  d3a <- icd10_sub_chapters[41]
+  icd10_sub_chapters[41] <- NULL
+  icd10_sub_chapters <- append(icd10_sub_chapters, d3a, after = 41)
+  if (save_pkg_data) .save_in_data_dir(icd10_sub_chapters)
   invisible(icd10_sub_chapters)
 }
-
-# nocov end
