@@ -1,4 +1,4 @@
-## ----setup, include=FALSE------------------------------------------------
+## ----setup, include=FALSE-----------------------------------------------------
 suppressWarnings({
   suppressPackageStartupMessages({
     loadNamespace("knitr") # for opts_chunk only
@@ -11,25 +11,26 @@ knitr::opts_chunk$set(
   comment = "#>"
 )
 
-## ----uranium-long--------------------------------------------------------
+## ----uranium-long-------------------------------------------------------------
 uranium_pathology[1:10, ]
 
-## ----explain10-----------------------------------------------------------
+## ----explain10----------------------------------------------------------------
 explain_code("R55")
 
-## ----uranium-wide--------------------------------------------------------
+## ----uranium-wide-------------------------------------------------------------
 head(uranium_pathology)
 
-## ----comorbidities-------------------------------------------------------
+## ----comorbidities------------------------------------------------------------
 quan_comorbidities <- comorbid(uranium_pathology, icd10_map_quan_elix)
 # see the first few rows and columns:
 quan_comorbidities[1:6, c(1, 3:10)]
 
-## ----tidy----------------------------------------------------------------
+## ----tidy---------------------------------------------------------------------
 comorbid_charlson(uranium_pathology, return_df = TRUE)[1:5, 1:5]
 
-## ----big-----------------------------------------------------------------
+## ----big----------------------------------------------------------------------
 # shuffle the rows:
+set.seed(1441)
 u <- uranium_pathology[sample(seq_len(nrow(uranium_pathology))), ]
 head(u)
 quan_comorbidities <- comorbid(u,
@@ -40,21 +41,21 @@ quan_comorbidities <- comorbid(u,
 # see the first few rows and columns:
 quan_comorbidities[1:6, c(1, 3:9)]
 
-## ----cholera-------------------------------------------------------------
+## ----cholera------------------------------------------------------------------
 # create trivial comorbidity map:
 cholera_typhoid_map <- list(cholera = "A00", typhoid = "A01")
 patients <- data.frame(patient = c("0001", "0001", "0002"),
                        code = c("A001234567", "A01", "A019"))
 comorbid(patients , map = cholera_typhoid_map)
 
-## ----htncx---------------------------------------------------------------
+## ----htncx--------------------------------------------------------------------
 icd10_map_quan_elix$HTNcx
 
-## ----setuppcs, echo = FALSE----------------------------------------------
+## ----setuppcs, echo = FALSE---------------------------------------------------
 n <- 10
 nm <- "code"
-pcs_sample <- sample(unname(unlist(icd10_map_ahrq_pcs)), n)
 set.seed(1441)
+pcs_sample <- sample(unname(unlist(icd10_map_ahrq_pcs)), n)
 pts <- data.frame(id = sample(LETTERS, n),
                   pc = pcs_sample)
 res <- icd10_comorbid(pts,
