@@ -2,6 +2,6 @@
 #define FASTINTTOSTRING_H_
 
 #include "icd_types.h"
-Rcpp::CharacterVector fastIntToStringRcpp(Rcpp::IntegerVector x);
+CV fastIntToStringRcpp(Rcpp::IntegerVector x);
 
 #endif /* FASTINTTOSTRING_H_ */
