@@ -1,28 +1,14 @@
-// Copyright (C) 2014 - 2018  Jack O. Wasey
-//
-// This file is part of icd.
-//
-// icd is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// icd is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with icd. If not, see <http://www.gnu.org/licenses/>.
-
 #ifndef ICD_TYPES_H_
 #define ICD_TYPES_H_
 
-#include <Rcpp.h>
-#include <vector>
+// also add LinkingTo element in DESCRIPTION to enable
+#include <Eigen/SparseCore>
+#include <RcppEigen.h>
+
 #include <string>
 #include <unordered_map>
 #include <unordered_set>
+#include <vector>
 typedef std::string Str;
 typedef std::vector<Str> VecStr;
 typedef std::vector<int> VecInt;
@@ -40,12 +26,12 @@ typedef VecInt NewOutPt;
 typedef std::vector<NewOutPt> NewOut;
 typedef VecVecInt::iterator NewOutIt;
 typedef std::unordered_map<std::string, VecInt::size_type> VisLk;
+typedef std::unordered_map<std::string, int> RelMap;
+typedef std::pair<std::string, int> RelPair;
 typedef std::unordered_set<std::string> icd_set;
+typedef std::unordered_set<std::string> US;
 typedef Rcpp::CharacterVector CV;
 
-#include <RcppEigen.h> // also add LinkingTo element in DESCRIPTION to enable
-#include <Eigen/SparseCore>
-
 typedef int SparseValue;
 typedef Eigen::Triplet<SparseValue> Triplet;
 typedef Eigen::SparseMatrix<SparseValue, Eigen::RowMajor> PtsSparse;
