@@ -1,12 +1,9 @@
-
 context("attributes")
 
 test_that("attribute is set by different mechanisms", {
   j <- "100"
-  expect_false(is.short_diag(j, must_work = TRUE))
-  expect_false(is.decimal_diag(j, must_work = TRUE))
-  expect_null(is.short_diag(j))
-  expect_null(is.decimal_diag(j))
+  expect_false(is.short_diag(j))
+  expect_false(is.decimal_diag(j))
   attr(j, "icd_short_diag") <- TRUE
   expect_true(is.short_diag(j))
   expect_false(is.decimal_diag(j))
@@ -24,16 +21,13 @@ test_that("attribute is set by different mechanisms", {
   expect_false(attr(k, "icd_short_diag"))
   k <- as.short_diag("753")
   expect_true(attr(k, "icd_short_diag"))
-
 })
 
 
 test_that("attribute is set by different mechanisms with icd_ functions", {
   j <- "100"
-  expect_false(is.icd_short_diag(j, must_work = TRUE))
-  expect_false(is.icd_decimal_diag(j, must_work = TRUE))
-  expect_null(is.icd_short_diag(j))
-  expect_null(is.icd_decimal_diag(j))
+  expect_false(is.icd_short_diag(j))
+  expect_false(is.icd_decimal_diag(j))
   attr(j, "icd_short_diag") <- TRUE
   expect_true(is.icd_short_diag(j))
   expect_false(is.icd_decimal_diag(j))
@@ -51,5 +45,4 @@ test_that("attribute is set by different mechanisms with icd_ functions", {
   expect_false(attr(k, "icd_short_diag"))
   k <- as.icd_short_diag("753")
   expect_true(attr(k, "icd_short_diag"))
-
 })
